CompositionFunctionApproximator
===============================

*Subclasses*

.. toctree::
   :maxdepth: 1

   RegressionCFA

.. toctree::
   :maxdepth: 2

.. automodule:: psyneulink.core.compositions.compositionfunctionapproximator
   :members:
